@@ -5,8 +5,7 @@ use warnings;
 BEGIN {
 	use Exporter ();
 	our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
-	$VERSION = "0.1";
-	#$AUTHOR  = "Vilas (vilas\@fiserlab.org )";
+	$VERSION = "0.01";
 	@ISA = qw(Exporter);
 
 	# name of the functions to export
@@ -15,21 +14,6 @@ BEGIN {
 	# symbols to export on request
 	@EXPORT_OK   = qw(recalc);
 }
-=for
-	getcoords 
-	get_axis 
-	COM2 
-	calculate_axis 
-	calc_I 
-	calc_evec 
-	projectpoint 
-	find_eigsmin 
-	find_roots 
-	cross 
-	dot 
-	unit 
-	norm
-=cut  
 
 our @EXPORT_OK;
 use List::Util qw(max maxstr min minstr);
@@ -47,13 +31,38 @@ Version 0.01
 
 our $VERSION = '0.01';
 
-=head2 getcoords 
+=head1 SYNOPSIS
+
+Subroutines for Geometric Calculations using atomic coordinates obtained from
+the PDB file (used in the generation of the dynamic database). 
+
+=head1 SUBROUTINES
+
+    getcoords 
+    get_axis 
+    COM2 
+    calculate_axis 
+    calc_I 
+    calc_evec 
+    projectpoint 
+    find_eigsmin 
+    find_roots 
+    cross 
+    dot 
+    unit 
+    norm
+
+=cut
+
+=head1 getcoords
 
     This subroutine gets the coordinates of a given type of atom from the PDB file
-    
+   
+    Usage: 
     my @ca = getcoords( \@idtable, \@lm, 'CA', $ArrayRef_coordchain);   
 
 =cut
+
 sub getcoords {
 
     my ( $data, $landmarks, $string, $ArrayRef_coordchain ) = @_;
@@ -608,4 +617,83 @@ sub norm {
     my $res = ( $v[0]**2 + $v[1]**2 + $v[2]**2 )**(0.5);
     return $res;
 }
+
+=head1 AUTHORS
+
+Fiserlab Members , C<< <andras at fiserlab.org> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>. 
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc GeometricMeasurements
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=.>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/.>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/.>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/./>
+
+=back
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 Fiserlab Members .
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified
+Versions is governed by this Artistic License. By using, modifying or
+distributing the Package, you accept this license. Do not use, modify,
+or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made
+by someone other than you, you are nevertheless required to ensure that
+your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service
+mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge
+patent license to make, have made, use, offer to sell, sell, import and
+otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by the
+Package. If you institute patent litigation (including a cross-claim or
+counterclaim) against any party alleging that the Package constitutes
+direct or contributory patent infringement, then this Artistic License
+to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
+AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
+THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
+YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
+CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
+EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+
+=cut
+
 1;
