@@ -13,13 +13,11 @@ BEGIN {
     # name of the functions to export
     @EXPORT_OK = qw(
 	calc_geom 
-	check_file 
 	exist_pdb_code_on_obsoletes 
 	exist_pdb_code_on_uncompressed 
     exist_pdb_code_on_alternate
-    exist_pdb_code_on_remodelled
 	get_full_path_name_for_pdb_code
-    get_full_path_name_for_pdb_code_old 
+    get_full_path_name_for_pdb_code_alternate
      _getReadingFileHandle
 	get_from_file 
 	translate 
@@ -75,11 +73,11 @@ use Config::Simple;
 my $config_file = $ENV{'SMOTIFTF_CONFIG_FILE'};
 croak "Environmental variable SMOTIFTF_CONFIG_FILE should be set" unless $config_file;
 
-my $cfg      = new Config::Simple($config_file);
-my $PDB      = $cfg->param( -block => 'pdb' );
-my $PDB_PATH = $PDB->{'pdb_path'};
+my $cfg              = new Config::Simple($config_file);
+my $PDB              = $cfg->param( -block => 'pdb' );
+my $PDB_DIR          = $PDB->{'uncompressed'};
+my $PDB_OBSOLETES    = $PDB->{'obsoletes'};
 my $USER_SPECIFIC_PDB_PATH = $PDB->{'user_specific_pdb_path'};
-my $REMODELLED_PDB_PATH    = $PDB->{'remodeled_pdb_path'};
 
 my $host = "";
 
@@ -135,23 +133,6 @@ sub calc_geom {
     return ( $delta, $theta, $rho );
 }
 
-=head2 check_file 
-	
-	subroutine to check if pdb file exists in the PDB flat-file database
-=cut
-sub check_file {
-
-    my ($name) = @_;
-    croak unless $name;
-
-    my $pdb_file_name = "pdb" . $name . '.ent';
-    my $filename      = "$PDB_PATH/uncompressed/$pdb_file_name";
-    my $filename2     = "$PDB_PATH/obsoletes/$pdb_file_name";
-    my $check         = 1;
-    open( FILE1, $filename ) or open( FILE1, $filename2 ) or $check = 0;
-    return $check;
-}
-
 =head2 _getReadingFileHandle
 	subroutine to get a reading file handle
         for a file.
@@ -180,13 +161,14 @@ sub _getReadingFileHandle {
 	return undef if not file was found
 	
         exist_pdb_code_on_obsoletes
-	input  : pdb_code (4fab)
+	input  : pdb_code (4fab), chain_id
 	return : full path name
 
 =cut
 sub exist_pdb_code_on_obsoletes {
-    my ($pdb_code) = @_;
+    my ($pdb_code, $chain) = @_;
     croak "exist_pdb_code_on_obsoletes: pdb_code is required" unless $pdb_code;
+	croak "exist_pdb_code_on_obsoletes: chain is required" unless defined $chain;
 
     chomp $pdb_code;
     croak "$pdb_code does not look like a four-letter PDB_CODE"
@@ -195,17 +177,30 @@ sub exist_pdb_code_on_obsoletes {
     my $pdb_file_name    = "pdb" . $pdb_code . '.ent';
     my $pdb_file_name_gz = "pdb" . $pdb_code . '.ent.gz';
 
-    my $uncompressed = "$PDB_PATH/obsoletes/$pdb_file_name";
-    my $compressed   = "$PDB_PATH/obsoletes/$pdb_file_name_gz";
+	my $pdb_file_name_ch    = 'pdb' . $pdb_code . $chain . '.ent';
+    my $pdb_file_name_ch_gz = 'pdb' . $pdb_code . $chain . '.ent.gz';
+
+    my $uncompressed = catfile ($PDB_OBSOLETES, $pdb_file_name);
+    my $compressed   = catfile ($PDB_OBSOLETES, $pdb_file_name_gz);
+
+	my $uncompressed_ch = catfile ($PDB_OBSOLETES, $pdb_file_name_ch);
+    my $compressed_ch   = catfile ($PDB_OBSOLETES, $pdb_file_name_ch_gz);
 
     # try uncompressed pdb filename existence
     if ( -e $uncompressed ) {
         return $uncompressed;
     }
-
     # try compressed file
     elsif ( -e $compressed ) {
         return $compressed;
+    }
+	# try uncompressed file with chain
+	elsif ( -e $uncompressed_ch ) {
+        return $uncompressed_ch;
+    }
+	# try compressed file with chain
+	elsif ( -e $compressed_ch ) {
+        return $compressed_ch;
     }
     else {
         return undef;
@@ -218,13 +213,14 @@ sub exist_pdb_code_on_obsoletes {
 	it will return the full path name if a match is found.
 	Return undef if not file was found
 	
-        input  : pdb_code (4fab)
+        input  : pdb_code (4fab), chain_id
 	return : full path name
 
 =cut
 sub exist_pdb_code_on_uncompressed {
-    my ($pdb_code) = @_;
+    my ($pdb_code, $chain) = @_;
     croak "exist_pdb_code_on_uncompressed: pdb_code is required" unless $pdb_code;
+	croak "exist_pdb_code_on_uncompressed: chain is required" unless defined $chain;
 
     chomp $pdb_code;
     croak "$pdb_code does not look like a four-letter PDB_CODE"
@@ -233,18 +229,31 @@ sub exist_pdb_code_on_uncompressed {
     my $pdb_file_name    = "pdb" . $pdb_code . '.ent';
     my $pdb_file_name_gz = "pdb" . $pdb_code . '.ent.gz';
 
-    my $uncompressed = "$PDB_PATH/uncompressed/$pdb_file_name";
-    my $compressed   = "$PDB_PATH/uncompressed/$pdb_file_name_gz";
+    my $pdb_file_name_ch    = 'pdb' . $pdb_code . $chain . '.ent';
+    my $pdb_file_name_ch_gz = 'pdb' . $pdb_code . $chain . '.ent.gz';
+
+	my $uncompressed = catfile ($PDB_DIR, $pdb_file_name);
+ 	my $compressed   = catfile ($PDB_DIR, $pdb_file_name_gz);
+
+	my $uncompressed_ch = catfile ($PDB_DIR, $pdb_file_name_ch);
+    my $compressed_ch   = catfile ($PDB_DIR, $pdb_file_name_ch_gz);
 
     # try uncompressed pdb filename existence
     if ( -e $uncompressed ) {
         return $uncompressed;
     }
-
     # try compressed file
     elsif ( -e $compressed ) {
         return $compressed;
     }
+	# try uncompressed file with chain
+	elsif ( -e $uncompressed_ch ) {
+        return $uncompressed_ch;
+    }
+    #try compressed file with chain
+    elsif ( -e $compressed_ch ) {
+    	return $compressed_ch;
+    }	
     else {
         return undef;
     }
@@ -257,87 +266,60 @@ sub exist_pdb_code_on_uncompressed {
         it will return the full path name if a match is found.
 	Return undef if not file was found
 	
-        input  : pdb_code (4fab)
+        input  : pdb_code (4fab), chain_id
 	return : full path name
 
 =cut
 sub exist_pdb_code_on_alternate { 
     my ($pdb_code, $chain) = @_;
     croak "exist_pdb_code_on_alternate: pdb_code is required" unless $pdb_code;
-    croak "exist_pdb_code_on_alternate: chain_id is required" unless $chain;
+	croak "exist_pdb_code_on_alternate: chain is required" unless defined $chain;
 
     chomp $pdb_code;
     croak "$pdb_code does not look like a four-letter PDB_CODE"
       unless $pdb_code =~ /[A-z0-9]{4}/;
 
-    my $pdb_file_name    = 'pdb' . $pdb_code . $chain . '.ent';
-    my $pdb_file_name_gz = 'pdb' . $pdb_code . $chain . '.ent.gz';
+    my $pdb_file_name    = 'pdb' . $pdb_code . '.ent';
+    my $pdb_file_name_gz = 'pdb' . $pdb_code . '.ent.gz';
+	
+	my $pdb_file_name_ch    = 'pdb' . $pdb_code . $chain . '.ent';
+    my $pdb_file_name_ch_gz = 'pdb' . $pdb_code . $chain . '.ent.gz';
 
     my $uncompressed = catfile ($USER_SPECIFIC_PDB_PATH, $pdb_file_name);
     my $compressed   = catfile ($USER_SPECIFIC_PDB_PATH, $pdb_file_name_gz);
 
-    # try uncompressed pdb filename existence
-    if ( -e $uncompressed ) {
-        return $uncompressed;
-    }
-
-    # try compressed file
-    elsif ( -e $compressed ) {
-        return $compressed;
-    }
-    else {
-        return undef;
-    }
-}
-
-=head2 exist_pdb_code_on_remodelled
-
-    check if a four-letters pdb code exist in user defined remodelled
-    PDB folder
-        it will return the full path name if a match is found.
-    Return undef if not file was found
-    
-        input  : pdb_code (4fab)
-    return : full path name
-
-=cut
-sub exist_pdb_code_on_remodelled {
-    my ($pdb_code, $chain) = @_;
-    croak "exist_pdb_code_on_alternate: pdb_code is required" unless $pdb_code;
-    croak "exist_pdb_code_on_alternate: Chain ID is required" unless $chain;
-
-    chomp $pdb_code;
-    croak "$pdb_code does not look like a four-letter PDB_CODE"
-      unless $pdb_code =~ /[A-z0-9]{4}/;
-
-    my $pdb_file_name    = 'pdb' . $pdb_code . $chain . '.ent';
-    my $pdb_file_name_gz = 'pdb' . $pdb_code . $chain . '.ent.gz';
-
-    my $uncompressed = catfile ($REMODELLED_PDB_PATH, $pdb_file_name);
-    my $compressed   = catfile ($REMODELLED_PDB_PATH, $pdb_file_name_gz);
+	my $uncompressed_ch = catfile ($USER_SPECIFIC_PDB_PATH, $pdb_file_name_ch);
+	my $compressed_ch   = catfile ($USER_SPECIFIC_PDB_PATH, $pdb_file_name_ch_gz);
 
     # try uncompressed pdb filename existence
     if ( -e $uncompressed ) {
         return $uncompressed;
     }
-
     # try compressed file
     elsif ( -e $compressed ) {
         return $compressed;
     }
+	#try uncompressed file with chain
+	elsif ( -e $uncompressed_ch ) {
+ 		return $uncompressed_ch;
+	}
+	#try compressed file with chain
+	elsif ( -e $compressed_ch ) {
+ 		return $compressed_ch;
+ 	}
     else {
         return undef;
     }
 }
 
-=head2 get_full_path_name_for_pdb_code
+=head2 get_full_path_name_for_pdb_code_alternate
 	Return a fullpath name for a given four-letter PDB code	
-        It will look in remodelled_PDB directory
+        It will look in USER_SPECIFIC PDB directory
 
         die if not match found
 
 =cut
-sub get_full_path_name_for_pdb_code {
+sub get_full_path_name_for_pdb_code_alternate {
     use Data::Dumper;
     my ($pdb_code, $chain) = @_;
    
@@ -349,8 +331,8 @@ sub get_full_path_name_for_pdb_code {
 	    print Dumper(\@_);
     }
 
-    croak "get_full_path_name_for_pdb_code: pdb_code is required" unless $pdb_code;
-    croak "get_full_path_name_for_pdb_code: Chain ID is required" unless $chain;
+    croak "get_full_path_name_for_pdb_code_alternate: pdb_code is required" unless $pdb_code;
+    croak "get_full_path_name_for_pdb_code_alternate: Chain ID is required" unless $chain;
 
     chomp $pdb_code;
     croak "$pdb_code does not look like a four-letter PDB_CODE"
@@ -358,26 +340,23 @@ sub get_full_path_name_for_pdb_code {
 
     my $path;
     
-    $path = exist_pdb_code_on_remodelled($pdb_code, $chain);
-    return $path if $path;
-
     $path = exist_pdb_code_on_alternate($pdb_code, $chain);
     return $path if $path;
 
-    croak "Could not find $pdb_code $chain on $REMODELLED_PDB_PATH"
+    croak "Could not find $pdb_code $chain on $USER_SPECIFIC_PDB_PATH"
       unless $path;
 }
 
-=head2 get_full_path_name_for_pdb_code_old
+=head2 get_full_path_name_for_pdb_code
     Return a fullpath name for a given four-letter PDB code 
         It will look in obsoletes and uncompressed directories
 
         die if not match found
 
 =cut
-sub get_full_path_name_for_pdb_code_old {
+sub get_full_path_name_for_pdb_code {
     use Data::Dumper;
-    my ($pdb_code) = @_;
+    my ($pdb_code, $chain) = @_;
 
     if ($DEBUG){
         my  ($package, $filename, $line) = caller;
@@ -387,23 +366,24 @@ sub get_full_path_name_for_pdb_code_old {
         print Dumper(\@_);
     }
 
-    croak "get_full_path_name_for_pdb_code_old: pdb_code is required" unless $pdb_code;
+    croak "get_full_path_name_for_pdb_code: pdb_code is required" unless $pdb_code;
+	croak "get_full_path_name_for_pdb_code: pdb_code is required" unless defined $chain;
 
     chomp $pdb_code;
     croak "$pdb_code does not look like a four-letter PDB_CODE"
       unless $pdb_code =~ /[A-z0-9]{4}/;
 
     my $path;
-    $path = exist_pdb_code_on_uncompressed($pdb_code);
+    $path = exist_pdb_code_on_uncompressed($pdb_code, $chain);
     return $path if $path;
 
-    $path = exist_pdb_code_on_obsoletes($pdb_code);
+    $path = exist_pdb_code_on_obsoletes($pdb_code, $chain);
     return $path if $path;
 
-    $path = exist_pdb_code_on_alternate($pdb_code);
+    $path = exist_pdb_code_on_alternate($pdb_code, $chain);
     return $path if $path;
 
-    croak "Could not find $pdb_code on $PDB_PATH or $USER_SPECIFIC_PDB_PATH"
+    croak "Could not find $pdb_code on $PDB_DIR or $PDB_OBSOLETES or $USER_SPECIFIC_PDB_PATH"
       unless $path;
 }
 
