@@ -44,10 +44,12 @@ our @EXPORT_OK;
 # This declares the named variables as package globals in the current package.
 our $PDB_DIR; 
 our $PDB_OBSOLETES;
+our $USER_SPECIFIC_PDB_PATH;
 
 use File::Find::Rule;
 use Data::Dumper;
 use Carp;
+use File::Spec::Functions qw(catfile);
 
 #use lib "/usr/local/lib/perl/JOELIB/PDB/";
 use SmotifTF::PDB::PDBCoordinateSectionParse qw(
@@ -57,13 +59,26 @@ use SmotifTF::PDB::PDBCoordinateSectionParse qw(
 	GetPDBHetatmRecordFields
 );
 
+#
+# locate_pdb_file
+#
+# It will look for pdb files on
+# $PDB_DIR
+# $PDB_OBSOLETES
+# $USER_SPECIFIC_PDB_PATH
+# in THAT order.
+#
+#$USER_SPECIFIC_PDB_PATH it could use dfor REMODEL_PDB
+#
+
 sub locate_pdb_file {
 
     my %args = (
         pdb_code           => '',
-        chain               => '',
+        chain              => '',
         pdb_path           => '',
         pdb_obsoletes_path => '',
+		user_specific_pdb_path => '',
         @_,
     );
 
@@ -71,14 +86,17 @@ sub locate_pdb_file {
     my $chain              = $args{'chain'}              || undef;
     my $pdb_path           = $args{'pdb_path'}           || undef;
     my $pdb_obsoletes_path = $args{'pdb_obsoletes_path'} || undef;
+	my $user_specific_pdb_path = $args{'user_specific_pdb_path'} || undef;
 
-    die "pdb_code is required"         unless $pdb_code;
-    die "chain is required"            unless defined $chain;
-    die "pdb_path is required"         unless $pdb_path;
+    die "pdb_code is required"           unless $pdb_code;
+    die "chain is required"              unless defined $chain;
+    die "pdb_path is required"           unless $pdb_path;
     die "pdb_obsoletes_path is required" unless $pdb_obsoletes_path;
+	die "user_specific_pdb_path is required" unless $user_specific_pdb_path;
 
     die "PDB_DIR       is not defined" unless $PDB_DIR;
     die "PDB_OBSOLETES is not defined" unless $PDB_OBSOLETES;
+	die "USER_SPECIFIC_PDB_PATH is not defined" unless $USER_SPECIFIC_PDB_PATH;
     
     $pdb_code   = lc $pdb_code;
 
@@ -94,6 +112,9 @@ sub locate_pdb_file {
 
     $full_path_name = _get_full_path_name($pdb_code, $chain, $PDB_OBSOLETES);
     return $full_path_name if $full_path_name;
+
+	$full_path_name = _get_full_path_name($pdb_code, $chain, $USER_SPECIFIC_PDB_PATH);
+ 	return $full_path_name if $full_path_name;
 }
 
 sub _get_full_path_name {
@@ -101,19 +122,48 @@ sub _get_full_path_name {
 
     my ($pdb_code_id, $chain, $path) = @_; 
 
-    my $rule =  File::Find::Rule->new;
-    $rule->file;
+    #my $rule =  File::Find::Rule->new;
+    #$rule->file;
 
-    my $file = $pdb_code_id.$chain;
+    my $file1 = "pdb" . $pdb_code_id . ".ent";
+	my $file2 = "pdb" . $pdb_code_id . ".ent.gz";
+    # looking for remodel pdb file
+	my $file3 = "pdb" . $pdb_code_id . $chain . ".ent";
+	my $file4 = "pdb" . $pdb_code_id . $chain . ".ent.gz";
+
+	my $full_name1 = catfile ($path, $file1);
+	my $full_name2 = catfile ($path, $file2);
+	my $full_name3 = catfile ($path, $file3);
+	my $full_name4 = catfile ($path, $file4);
+
+	if (-e $full_name1) {
+		return $full_name1;
+	}
+
+	elsif (-e $full_name2) {
+		return $full_name2;
+	}
+
+	elsif (-e $full_name3) {
+        return $full_name3;
+    }
+
+	elsif (-e $full_name4) {
+        return $full_name4;
+    }
+
+	else {
+		return undef;
+	}
     
-    print "Looking for $file ... \n";
-    $rule->name( qr/$file/ );
-    my @file_full_path = $rule->in($path);
+    #print "Looking for $file ... \n";
+    #$rule->name( qr/$file/ );
+    #my @file_full_path = $rule->in($path);
 
     #croak "$file_name was not found in ".$self->{$path} 
     #    unless @file_full_path;
     
-    return $file_full_path[0] || undef;
+    #return $file_full_path[0] || undef;
 }
 
 sub ParsePDBfile {
@@ -131,8 +181,9 @@ sub ParsePDBfile {
         chain              => $chain,
         pdb_path           => $PDB_DIR,
         pdb_obsoletes_path => $PDB_OBSOLETES,
+		user_specific_pdb_path => $USER_SPECIFIC_PDB_PATH,
     );
-    die "ParsePDBfile could not find pdb file for $pdb_code $chain at $PDB_DIR $PDB_OBSOLETES" 
+    die "ParsePDBfile could not find pdb file for $pdb_code $chain at $PDB_DIR or $PDB_OBSOLETES or $USER_SPECIFIC_PDB_PATH" 
         unless $pdbfile; 
     
     print "ParsePDBfile pdbfile = $pdbfile\n";
