@@ -7,8 +7,8 @@ use warnings;
 use SmotifTF::GeometricalCalculations;
 use SmotifTF::StatisticalPotential;
 use Math::Trig;
-use SmotifTF::MYSQLSmotifs;
 use Data::Dumper;
+use Carp;
 
 =head1 NAME
 
@@ -330,7 +330,7 @@ sub add_motif_from_file {
 		# SmotifTF::GeometricalCalculations::getnid(\@proptable, \@idtable);
 		# print Dumper(\@proptable);
 		# print Dumper(\@idtable);
-                SmotifTF::MYSQLSmotifs::getnid(\@proptable, \@idtable);
+		croak "Array dimension for Smotif definition is incorrect";
 	}
 	my @ca=SmotifTF::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
 	my @n=SmotifTF::GeometricalCalculations::get_from_file(\@idtable,\@lm,'N',\$seq);
@@ -388,7 +388,7 @@ sub add_partial_motif {
 		@idtable=@proptable;
 	} else {
 		#SmotifTF::GeometricalCalculations::getnid(\@proptable, \@idtable);
-		SmotifTF::MYSQLSmotifs::getnid(\@proptable, \@idtable);
+		croak "Array dimension for Smotif definition is incorrect";
 	}
 	my @ca=SmotifTF::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
 	my @n=SmotifTF::GeometricalCalculations::get_from_file(\@idtable,\@lm,'N',\$seq);
