@@ -1,6 +1,6 @@
 package SmotifTF::Psipred;
 
-use v5.8.8;
+# use v5.8.8;
 use strict;
 use warnings;
 
